Struct WalletVtxo

pub struct WalletVtxo {
    pub vtxo: Vtxo<Full>,
    pub state: VtxoState,
}
A wallet-owned Vtxo paired with its current tracked state.

Fields

vtxo: Vtxo<Full>

The underlying Vtxo.

state: VtxoState

The current tracked state for [WalletVtxo::into_vtxo].

Methods from Deref<Target = Vtxo<Full>>

pub fn id(&self) -> VtxoId

Get the identifier for this Vtxo.

This is the same as Vtxo::point but encoded as a byte array.

pub fn point(&self) -> OutPoint

The outpoint from which to build forfeit or arkoor txs.

This can be an on-chain utxo or an off-chain vtxo.

pub fn amount(&self) -> Amount

The amount of the Vtxo.

pub fn chain_anchor(&self) -> OutPoint

The UTXO that should be confirmed for this Vtxo to be valid.

It is the very root of the VTXO.

pub fn policy(&self) -> &P

The output policy of this VTXO.

pub fn policy_type(&self) -> VtxoPolicyKind

The output policy type of this VTXO.

pub fn expiry_height(&self) -> u32

The expiry height of the Vtxo.

pub fn server_pubkey(&self) -> PublicKey

The server pubkey used in arkoor transitions.

pub fn exit_delta(&self) -> u16

The relative timelock block delta used for exits.

pub fn output_taproot(&self) -> TaprootSpendInfo

The taproot spend info for the output of this Vtxo.

pub fn output_script_pubkey(&self) -> ScriptBuf

The scriptPubkey of the output of this Vtxo.

pub fn txout(&self) -> TxOut

The transaction output (eventual UTXO) of this Vtxo.

pub fn to_bare(&self) -> Vtxo<Bare, P>

Convert to a bare VTXO, Vtxo

pub fn exit_depth(&self) -> u16

Returns the total exit depth (including OOR depth) of the vtxo.

pub fn past_arkoor_pubkeys(&self) -> Vec<Vec<PublicKey>>

Iterate over all oor transitions in this VTXO

The outer Vec cointains one element for each transition. The inner Vec contains all pubkeys within that transition.

This does not include the current arkoor pubkey, for that use Vtxo::arkoor_pubkey.

pub fn has_all_witnesses(&self) -> bool

Whether all transaction witnesses are present

It is possible to represent unsigned or otherwise unfinished VTXOs, for which this method will return false.

pub fn is_standard(&self) -> bool

Check if this VTXO is standard for relay purposes

A VTXO is standard if:

  • Its own output is standard
  • all sibling outputs in the exit path are standard
  • each part of the exit path should have a P2A output
pub fn unlock_hash(&self) -> Option<Hash>

Returns the “hArk” unlock hash if this is a hArk leaf VTXO

pub fn transactions(&self) -> VtxoTxIter<'_, P>

Iterator that constructs all the exit txs for this Vtxo.

pub fn validate( &self, chain_anchor_tx: &Transaction, ) -> Result<(), VtxoValidationError>

Fully validate this VTXO and its entire transaction chain.

The chain_anchor_tx must be the tx with txid matching Vtxo::chain_anchor.

pub fn validate_unsigned( &self, chain_anchor_tx: &Transaction, ) -> Result<(), VtxoValidationError>

Validate VTXO structure without checking signatures.

pub fn user_pubkey(&self) -> PublicKey

Returns the user pubkey associated with this Vtxo.

pub fn arkoor_pubkey(&self) -> Option<PublicKey>

The public key used to cosign arkoor txs spending this Vtxo. This will return None if VtxoPolicy::is_arkoor_compatible returns false for this VTXO’s policy.